==> fox-1.1.1.tar.gz: fox/src/FoxCommandsHelper.php <==
<?php

declare(strict_types=1);

namespace Drupal\fox;

use Drupal\Core\Entity\EntityFieldManagerInterface;
use Drupal\Core\Entity\EntityTypeBundleInfoInterface;
use Drupal\Core\Entity\EntityTypeManagerInterface;
use Drupal\Core\StringTranslation\StringTranslationTrait;
use Drupal\fox\Plugin\FoxCommandsManager;

/**
 * Fox command helper class.
 */
class FoxCommandsHelper {

  use StringTranslationTrait;
  use FoxCommonFunctionsTrait;

  /**
   * Constructs a FoxCommandsHelper object.
   */
  public function __construct(
    private readonly EntityTypeManagerInterface $entityTypeManager,
    private readonly EntityTypeBundleInfoInterface $entityTypeBundleInfo,
    private readonly EntityFieldManagerInterface $entityFieldManager,
    private readonly FoxCommandsManager $foxCommandsManager,
  ) {}

  /**
   * Get entity type and bundle.
   *
   * @param array $parts
   *   Input parts.
   *
   * @return array
   *   Entity type and bundle.
   */
  public function getTypeBundle(array $parts): array {
    $entity_type = $parts[0];
    $bundle = $parts[1] ?? NULL;
    return [$entity_type, $bundle];
  }

  /**
   * Get entity query.
   *
   * @param string $entity_type
   *   Entity type.
   * @param string|null $bundle
   *   Bundle, if exists.
   *
   * @return \Drupal\Core\Entity\Query\QueryInterface
   *   Entity Query interface.
   */
  public function getEntityQuery(string $entity_type, $bundle = NULL) {
    $query = $this->entityTypeManager
      ->getStorage($entity_type)
      ->getQuery()
      ->accessCheck(TRUE);

    if (!empty($bundle)) {
      $bundle_key = $this->entityKey($entity_type, 'bundle');
      $query->condition($bundle_key, $bundle);
    }

    return $query;
  }

  /**
   * Get entity type manager.
   *
   * @return \Drupal\Core\Entity\EntityTypeManagerInterface
   *   Entity type manager.
   */
  public function entityTypeManager() {
    return $this->entityTypeManager;
  }

  /**
   * Get entity type bundle info.
   *
   * @return \Drupal\Core\Entity\EntityTypeBundleInfoInterface
   *   Entity type bundle info.
   */
  public function entityTypeBundleInfo() {
    return $this->entityTypeBundleInfo;
  }

  /**
   * Get entity field manager.
   *
   * @return \Drupal\Core\Entity\EntityFieldManagerInterface
   *   Entity field manager.
   */
  public function entityFieldManager() {
    return $this->entityFieldManager;
  }

  /**
   * Get the Fox commands manager.
   *
   * @return \Drupal\fox\Plugin\FoxCommandsManager
   *   Fox commands manager.
   */
  public function foxCommandsManager() {
    return $this->foxCommandsManager;
  }

  /**
   * Get entity type ID key.
   *
   * @param string $entity_type
   *   Entity type.
   * @param string $key
   *   Entity key ID.
   *
   * @return string
   *   Entity key value.
   */
  public function entityKey(string $entity_type, string $key) {
    return $this->entityTypeManager
      ->getDefinition($entity_type)
      ->getKey($key);
  }

  /**
   * Render string with parameters.
   *
   * @param string $template
   *   Text template.
   * @param array $variables
   *   Variables data.
   *
   * @return string
   *   Rendered string.
   */
  public function stringRender(string $template, array $variables = []) {
    $result = $template;

    if (!empty($variables)) {
      preg_match_all('/@([a-zA-Z0-9_]+)/', $result, $matches);
      if (count($matches) == 2) {
        $params = [];
        foreach ($matches[0] as $key => $value) {
          $variable = $variables[$matches[1][$key]] ?? NULL;
          if ($variable) {
            $params[$value] = $variable;
          }
        }

        if (!empty($params)) {
          // phpcs:disable
          $result = $this->t($result, $params);
          // phpcs:enable
        }
      }
    }

    return (string) $result;
  }

  /**
   * Get record info.
   *
   * @param array $variables
   *   Variables data.
   *
   * @return mix
   *   Entity error.
   */
  public function getEntity(array $variables) {
    $entity_type = $variables['entity_type'] ?? NULL;
    $id = $variables['id'] ?? NULL;

    if (empty($entity_type)) {
      return $this->errorReturn($this->t('Empty entity type. Use USE command.'));
    }

    if ($id === NULL) {
      return $this->errorReturn($this->t('Empty ID. Use GOTO command.'));
    }

    $entity = $this->entityTypeManager
      ->getStorage($entity_type)
      ->load($id);

    return $entity;
  }

  /**
   * Prepare value.
   *
   * @param string|array $value
   *   Original value.
   *
   * @return string
   *   Prepared value.
   */
  public function prepareValue($value) {
    if (is_array($value)) {
      $value = implode(' ', $value);
    }

    $value = trim($value);
    $value = trim($value, "\"'");
    return $value;
  }

  /**
   * Prepare parameters.
   *
   * @param array $params
   *   Input parameters.
   * @param bool $is_json
   *   Is JSON input.
   * @param string $delimiter
   *   Parameters delimiter.
   *
   * @return array
   *   Prepared parameters.
   */
  public function prepareParameters(array $params, bool $is_json = FALSE, $delimiter = ','): array {
    $param_str = implode(' ', $params);

    if ($is_json) {
      $pattern = '/(?<=])' . $delimiter . '/';
      $items = preg_split($pattern, $param_str);
      $items = array_map('trim', $items);
    }
    else {
      $items = explode($delimiter, $param_str);
    }

    return $items;
  }

  /**
   * Get options for command from parameters list.
   *
   * @param array $params
   *   Parameters list.
   * @param array $default_options
   *   Default parameters list.
   *
   * @return array
   *   Options and parameters list.
   */
  public function getOptions(array $params, array $default_options = []): array {
    $options = [];
    foreach ($params as $id => $param) {
      if (str_starts_with($param, '--')) {
        $parts = explode('=', $param);

        $key = substr(trim($parts[0]), 2);
        $value = isset($parts[1]) ? trim($parts[1]) : 1;
        $options[$key] = $value;
        unset($params[$id]);
      }
    }

    $options = array_merge($default_options, $options);

    return [
      'options' => $options,
      'params' => $params,
    ];
  }

}

==> fox-1.1.3.tar.gz: fox/src/FoxCommandsHelper.php <==
<?php

declare(strict_types=1);

namespace Drupal\fox;

use Drupal\Core\Entity\EntityFieldManagerInterface;
use Drupal\Core\Entity\EntityTypeBundleInfoInterface;
use Drupal\Core\Entity\EntityTypeManagerInterface;
use Drupal\Core\StringTranslation\StringTranslationTrait;
use Drupal\fox\Plugin\FoxCommandsManager;

/**
 * Fox command helper class.
 */
class FoxCommandsHelper {

  use StringTranslationTrait;
  use FoxCommonFunctionsTrait;

  /**
   * Constructs a FoxCommandsHelper object.
   */
  public function __construct(
    private readonly EntityTypeManagerInterface $entityTypeManager,
    private readonly EntityTypeBundleInfoInterface $entityTypeBundleInfo,
    private readonly EntityFieldManagerInterface $entityFieldManager,
    private readonly FoxCommandsManager $foxCommandsManager,
  ) {}

  /**
   * Get entity type and bundle.
   *
   * @param array $parts
   *   Input parts.
   *
   * @return array
   *   Entity type and bundle.
   */
  public function getTypeBundle(array $parts): array {
    $entity_type = $parts[0];
    $bundle = $parts[1] ?? NULL;
    return [$entity_type, $bundle];
  }

  /**
   * Get entity query.
   *
   * @param string $entity_type
   *   Entity type.
   * @param string|null $bundle
   *   Bundle, if exists.
   *
   * @return \Drupal\Core\Entity\Query\QueryInterface
   *   Entity Query interface.
   */
  public function getEntityQuery(string $entity_type, $bundle = NULL) {
    $query = $this->entityTypeManager
      ->getStorage($entity_type)
      ->getQuery()
      ->accessCheck(TRUE);

    if (!empty($bundle)) {
      $bundle_key = $this->entityKey($entity_type, 'bundle');
      $query->condition($bundle_key, $bundle);
    }

    return $query;
  }

  /**
   * Get entity type manager.
   *
   * @return \Drupal\Core\Entity\EntityTypeManagerInterface
   *   Entity type manager.
   */
  public function entityTypeManager() {
    return $this->entityTypeManager;
  }

  /**
   * Get entity type bundle info.
   *
   * @return \Drupal\Core\Entity\EntityTypeBundleInfoInterface
   *   Entity type bundle info.
   */
  public function entityTypeBundleInfo() {
    return $this->entityTypeBundleInfo;
  }

  /**
   * Get entity field manager.
   *
   * @return \Drupal\Core\Entity\EntityFieldManagerInterface
   *   Entity field manager.
   */
  public function entityFieldManager() {
    return $this->entityFieldManager;
  }

  /**
   * Get the Fox commands manager.
   *
   * @return \Drupal\fox\Plugin\FoxCommandsManager
   *   Fox commands manager.
   */
  public function foxCommandsManager() {
    return $this->foxCommandsManager;
  }

  /**
   * Get entity type ID key.
   *
   * @param string $entity_type
   *   Entity type.
   * @param string $key
   *   Entity key ID.
   *
   * @return string
   *   Entity key value.
   */
  public function entityKey(string $entity_type, string $key) {
    return $this->entityTypeManager
      ->getDefinition($entity_type)
      ->getKey($key);
  }

  /**
   * Render string with parameters.
   *
   * @param string $template
   *   Text template.
   * @param array $variables
   *   Variables data.
   *
   * @return string
   *   Rendered string.
   */
  public function stringRender(string $template, array $variables = []) {
    $result = $template;

    if (!empty($variables)) {
      preg_match_all('/@([a-zA-Z0-9_]+)/', $result, $matches);
      if (count($matches) == 2) {
        $params = [];
        foreach ($matches[0] as $key => $value) {
          $variable = $variables[$matches[1][$key]] ?? NULL;
          if ($variable) {
            $params[$value] = $variable;
          }
        }

        if (!empty($params)) {
          // phpcs:disable
          $result = $this->t($result, $params);
          // phpcs:enable
        }
      }
    }

    return (string) $result;
  }

  /**
   * Get record info.
   *
   * @param array $variables
   *   Variables data.
   *
   * @return mixed
   *   Entity error.
   */
  public function getEntity(array $variables) {
    $entity_type = $variables['entity_type'] ?? NULL;
    $id = $variables['id'] ?? NULL;

    if (empty($entity_type)) {
      return $this->errorReturn($this->t('Empty entity type. Use USE command.'));
    }

    if ($id === NULL) {
      return $this->errorReturn($this->t('Empty ID. Use GO command.'));
    }

    $entity = $this->entityTypeManager
      ->getStorage($entity_type)
      ->load($id);

    return $entity;
  }

  /**
   * Prepare value.
   *
   * @param string|array $value
   *   Original value.
   *
   * @return string
   *   Prepared value.
   */
  public function prepareValue($value) {
    if (is_array($value)) {
      $value = implode(' ', $value);
    }

    $value = trim($value);
    $value = trim($value, "\"'");
    return $value;
  }

  /**
   * Prepare parameters.
   *
   * @param array $params
   *   Input parameters.
   * @param bool $is_json
   *   Is JSON input.
   * @param string $delimiter
   *   Parameters delimiter.
   *
   * @return array
   *   Prepared parameters.
   */
  public function prepareParameters(array $params, bool $is_json = FALSE, $delimiter = ','): array {
    $param_str = implode(' ', $params);

    if ($is_json) {
      $pattern = '/(?<=])' . $delimiter . '/';
      $items = preg_split($pattern, $param_str);
      $items = array_map('trim', $items);
    }
    else {
      $items = explode($delimiter, $param_str);
    }

    return $items;
  }

  /**
   * Get options for command from parameters list.
   *
   * @param array $params
   *   Parameters list.
   * @param array $default_options
   *   Default parameters list.
   *
   * @return array
   *   Options and parameters list.
   */
  public function getOptions(array $params, array $default_options = []): array {
    $options = [];
    foreach ($params as $id => $param) {
      if (str_starts_with($param, '--')) {
        $parts = explode('=', $param);

        $key = substr(trim($parts[0]), 2);
        $value = isset($parts[1]) ? trim($parts[1]) : 1;
        $options[$key] = $value;
        unset($params[$id]);
      }
    }

    $options = array_merge($default_options, $options);

    return [
      'options' => $options,
      'params' => $params,
    ];
  }

}
